@@ -324,18 +324,27 @@ def wait_function_status(function, status=["Ready", "Failed"]):
     return function.status
 
 
-def list_services(tags=[]):
+def list_services(tags=[], env='prod'):
     """
-    List available services (i.e. CDF Functions) that match a set of tags.
+    List available services (i.e. CDF Functions) in an environment (dev, test or
+    prod) that match a set of tags.
     If not tags are provided, all services are listed.
     Input:
         - tags: ([string]): list of tags to search for in the function
         description
+        - env: (string) the environment, default is 'prod' (recommended)
     Output:
         - ([string]): list of function names (i.e. external_id's )
     """
+    def get_function_environment(function_name):
+        try:
+            return function_name.rsplit('-', 1)[1]
+        except IndexError:
+            return None
+    
     client = global_client["functions"]
-    functions = client.functions.list()
+    functions = [f for f in client.functions.list()
+                    if get_function_environment(f.external_id) == env]
     if tags:
         functions = [f.external_id for f in functions if 
         any([True if tag in f.description else False for tag in tags])
